The following commit has been merged in the master branch:
commit 6b62761d7c3f0db09371a24e8d32a2600cc91c5a
Author: Guillem Jover <[email protected]>
Date:   Fri Jul 16 20:31:54 2010 +0200

    Use earlier/later instead of smaller/bigger for comparison relationships
    
    Closes: #587641

diff --git a/debian/changelog b/debian/changelog
index 3ec70ef..de9672f 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -80,6 +80,8 @@ dpkg (1.15.8) UNRELEASED; urgency=low
     directory is not existent or writable. Closes: #581544
   * Properly compute the longest package description from all to be displayed
     on “dpkg-query --list”, so that it does not get incorrectly trimmed.
+  * Consistently use earlier/later instead of smaller/bigger when describing
+    comparison relationships. Closes: #587641
 
   [ Updated programs translations ]
   * Catalan (Guillem Jover).
diff --git a/lib/dpkg/pkg.c b/lib/dpkg/pkg.c
index f893732..7598860 100644
--- a/lib/dpkg/pkg.c
+++ b/lib/dpkg/pkg.c
@@ -34,9 +34,9 @@
  * @param b A pointer of a pointer to a struct pkginfo.
  *
  * @return An integer with the result of the comparison.
- * @retval -1 a is smaller than b.
+ * @retval -1 a is earlier than b.
  * @retval 0 a is equal to b.
- * @retval 1 a is greater than b.
+ * @retval 1 a is later than b.
  */
 int
 pkg_sorter_by_name(const void *a, const void *b)
diff --git a/scripts/Dpkg/Shlibs/Symbol.pm b/scripts/Dpkg/Shlibs/Symbol.pm
index 2b796d6..75f3d99 100644
--- a/scripts/Dpkg/Shlibs/Symbol.pm
+++ b/scripts/Dpkg/Shlibs/Symbol.pm
@@ -450,7 +450,7 @@ sub mark_found_in_library {
 # Sanitize the symbol when it is confirmed to be NOT found in
 # the respective library.
 # Mark as deprecated those that are no more provided (only if the
-# minver is bigger than the version where the symbol was introduced)
+# minver is later than the version where the symbol was introduced)
 sub mark_not_found_in_library {
     my ($self, $minver, $arch) = @_;
 
diff --git a/scripts/Dpkg/Version.pm b/scripts/Dpkg/Version.pm
index c8cb60b..8ab37f1 100644
--- a/scripts/Dpkg/Version.pm
+++ b/scripts/Dpkg/Version.pm
@@ -191,8 +191,8 @@ All the functions are exported by default.
 
 =item version_compare($a, $b)
 
-Returns -1 is $a is smaller than $b, 0 if they are equal and 1 if $a
-is bigger than $b.
+Returns -1 if $a is earlier than $b, 0 if they are equal and 1 if $a
+is later than $b.
 
 If $a or $b are not valid version numbers, it dies with an error.
 
@@ -271,8 +271,8 @@ sub version_normalize_relation($) {
 =item version_compare_string($a, $b)
 
 String comparison function used for comparing non-numerical parts of version
-numbers. Returns -1 is $a is smaller than $b, 0 if they are equal and 1 if $a
-is bigger than $b.
+numbers. Returns -1 if $a is earlier than $b, 0 if they are equal and 1 if $a
+is later than $b.
 
 The "~" character always sort lower than anything else. Digits sort lower
 than non-digits. Among remaining characters alphabetic characters (A-Za-z)
@@ -313,8 +313,8 @@ version or debian revision).
 
 Each parameter is split by version_split_digits() and resulting items
 are compared together.in digits and non-digits items that are compared
-together. As soon as a difference happens, it returns -1 if $a is smaller
-than $b, 0 if they are equal and 1 if $a is bigger than $b.
+together. As soon as a difference happens, it returns -1 if $a is earlier
+than $b, 0 if they are equal and 1 if $a is later than $b.
 
 =cut
 
diff --git a/scripts/dpkg-genchanges.pl b/scripts/dpkg-genchanges.pl
index ea23ab1..1b6fbf4 100755
--- a/scripts/dpkg-genchanges.pl
+++ b/scripts/dpkg-genchanges.pl
@@ -215,7 +215,7 @@ if (defined($prev_changelog) and
     version_compare_relation($changelog->{"Version"}, REL_LT,
                              $prev_changelog->{"Version"}))
 {
-    warning(_g("the current version (%s) is smaller than the previous one 
(%s)"),
+    warning(_g("the current version (%s) is earlier than the previous one 
(%s)"),
        $changelog->{"Version"}, $prev_changelog->{"Version"})
         # ~bpo and ~vola are backports and have lower version number by 
definition
         unless $changelog->{"Version"} =~ /~(?:bpo|vola)/;

diff --git a/scripts/Dpkg/Changelog.pm b/scripts/Dpkg/Changelog.pm
index d94761f..4303618 100644
--- a/scripts/Dpkg/Changelog.pm
+++ b/scripts/Dpkg/Changelog.pm
@@ -252,7 +252,7 @@ sub __sanity_check_range {
     }
     if ((defined($r->{since}) and not exists $versions{$r->{since}})) {
         warning(_g("'%s' option specifies non-existing version"), "since");
-        warning(_g("use newest entry that is smaller than the one specified"));
+        warning(_g("use newest entry that is earlier than the one specified"));
         foreach my $v (@versions) {
             if (version_compare_relation($v, REL_LT, $r->{since})) {
                 $r->{since} = $v;
@@ -260,7 +260,7 @@ sub __sanity_check_range {
             }
         }
         if (not exists $versions{$r->{since}}) {
             # No version was smaller, include all
             warning(_g("none found, starting from the oldest entry"));
             delete $r->{since};
             $r->{from} = $versions[-1];
@@ -268,7 +268,7 @@ sub __sanity_check_range {
     }
     if ((defined($r->{from}) and not exists $versions{$r->{from}})) {
         warning(_g("'%s' option specifies non-existing version"), "from");
-        warning(_g("use oldest entry that is bigger than the one specified"));
+        warning(_g("use oldest entry that is later than the one specified"));
         my $oldest;
         foreach my $v (@versions) {
             if (version_compare_relation($v, REL_GT, $r->{from})) {
@@ -279,12 +279,12 @@ sub __sanity_check_range {
             $r->{from} = $oldest;
         } else {
             warning(_g("no such entry found, ignoring '%s' parameter"), 
"from");
-            delete $r->{from}; # No version was bigger
+            delete $r->{from}; # No version was oldest
         }
     }
     if (defined($r->{'until'}) and not exists $versions{$r->{'until'}}) {
         warning(_g("'%s' option specifies non-existing version"), "until");
-        warning(_g("use oldest entry that is bigger than the one specified"));
+        warning(_g("use oldest entry that is later than the one specified"));
         my $oldest;
         foreach my $v (@versions) {
             if (version_compare_relation($v, REL_GT, $r->{'until'})) {
@@ -295,12 +295,12 @@ sub __sanity_check_range {
             $r->{'until'} = $oldest;
         } else {
             warning(_g("no such entry found, ignoring '%s' parameter"), 
"until");
-            delete $r->{'until'}; # No version was bigger
+            delete $r->{'until'}; # No version was oldest
         }
     }
     if (defined($r->{to}) and not exists $versions{$r->{to}}) {
         warning(_g("'%s' option specifies non-existing version"), "to");
-        warning(_g("use newest entry that is smaller than the one specified"));
+        warning(_g("use newest entry that is earlier than the one specified"));
         foreach my $v (@versions) {
             if (version_compare_relation($v, REL_LT, $r->{to})) {
                 $r->{to} = $v;
@@ -308,7 +308,7 @@ sub __sanity_check_range {
             }
         }
         if (not exists $versions{$r->{to}}) {
             # No version was smaller
             warning(_g("no such entry found, ignoring '%s' parameter"), "to");
             delete $r->{to};
         }
@@ -260,7 +260,7 @@ sub __sanity_check_range {
         }
         if (not exists $versions{$r->{since}}) {
-            # No version was smaller, include all
+            # No version was earlier, include all
             warning(_g("none found, starting from the oldest entry"));
             delete $r->{since};
@@ -308,7 +308,7 @@ sub __sanity_check_range {
         }
         if (not exists $versions{$r->{to}}) {
-            # No version was smaller
+            # No version was earlier
             warning(_g("no such entry found, ignoring '%s' parameter"), "to");
             delete $r->{to};
-- 
dpkg's main repository


-- 
To UNSUBSCRIBE, email to [email protected]
with a subject of "unsubscribe". Trouble? Contact [email protected]

Reply via email to